# Changelog

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Effort-based Versioning](https://jacobtomlinson.dev/effver/).
(Changes to features documented as "experimental" will not increment macro and meso version numbers.)

## [Unreleased]

(no changes yet)

## [1.0.2] - 2025-10-12

Bug fixes.

### Fixed

- The `Slide.get_hits` method now measures the distance from the center of mass to the waypoints.
- Documentat `Slide.plot` and `Slide.get_hits` in the README file.

## [1.0.1] - 2025-10-12

Small improvements.

### Changed

- Improved README.
- Improved clarity of first and last target.
- Simplify altitude colormap.
- Improve the brutal bends slide.

## [1.0.0] - 2025-10-11

Initial release, just to get things started.

[Unreleased]: https://github.com/molmod/soapboxslide
[1.0.2]: https://github.com/molmod/soapboxslide/releases/tag/v1.0.2
[1.0.1]: https://github.com/molmod/soapboxslide/releases/tag/v1.0.1
[1.0.0]: https://github.com/molmod/soapboxslide/releases/tag/v1.0.0
